@@ -21,16 +21,17 @@ from StringIO import StringIO
 import shutil
 import subprocess
 from robot import run, rebot
+from robot import __version__ as ROBOT_VERSION
 from robot.api import ExecutionResult
 from robot.result.visitor import ResultVisitor
 from multiprocessing.pool import ThreadPool
-from tempfile import mkdtemp
 from robot.run import USAGE
 from robot.utils import ArgumentParser
 import signal
 
 CTRL_C_PRESSED = False
 
+
 def execute_and_wait_with(args):
     global CTRL_C_PRESSED
     if CTRL_C_PRESSED:
@@ -41,11 +42,20 @@ def execute_and_wait_with(args):
     outs_dir = os.path.join(outs_dir, suite_name)
     cmd = command + _options_for_custom_executor(options, outs_dir, suite_name) + datasources
     cmd = [c if ' ' not in c else '"%s"' % c for c in cmd]
+    os.makedirs(outs_dir)
+    with open(os.path.join(outs_dir, 'stdout.txt'), 'w') as stdout, \
+        open(os.path.join(outs_dir, 'stderr.txt'), 'w') as stderr:
+            process, rc = _run(cmd, stderr, stdout, suite_name, verbose)
+    if rc != 0:
+        print _execution_failed_message(suite_name, process, rc, verbose)
+    else:
+        print 'PASSED %s' % suite_name
 
+def _run(cmd, stderr, stdout, suite_name, verbose):
     process = subprocess.Popen(' '.join(cmd),
-                          shell=True,
-                          stderr=subprocess.PIPE,
-                          stdout=subprocess.PIPE)
+                               shell=True,
+                               stderr=stderr,
+                               stdout=stdout)
     if verbose:
         print '[PID:%s] EXECUTING PARALLEL SUITE %s with command:\n%s' % (process.pid, suite_name, ' '.join(cmd))
     else:
@@ -54,19 +64,12 @@ def execute_and_wait_with(args):
     while rc is None:
         rc = process.poll()
         time.sleep(0.1)
-    if rc != 0:
-        print _execution_failed_message(suite_name, process, rc, verbose)
-    else:
-        print 'PASSED %s' % suite_name
+    return process, rc
 
 def _execution_failed_message(suite_name, process, rc, verbose):
     if not verbose:
         return 'FAILED %s' % suite_name
-    msg = ['Execution failed in %s with %d failing test(s)' % (suite_name, rc)]
-    stderr = process.stderr.read().strip()
-    if stderr:
-        msg += ['<< STDERR >>', stderr, '<< END OF STDERR >>']
-    return '\n'.join(msg)
+    return 'Execution failed in %s with %d failing test(s)' % (suite_name, rc)
 
 def _options_for_custom_executor(*args):
     return _options_to_cli_arguments(_options_for_executor(*args))
@@ -78,7 +81,8 @@ def _options_for_executor(options, outs_dir, suite_name):
     options['suite'] = suite_name
     options['outputdir'] = outs_dir
     options['monitorcolors'] = 'off'
-    options['monitormarkers'] = 'off'
+    if ROBOT_VERSION >= '2.8':
+        options['monitormarkers'] = 'off'
     return options
 
 def _options_to_cli_arguments(opts):
@@ -150,13 +154,17 @@ def _options_for_dryrun(options, outs_dir):
     options = options.copy()
     options['log'] = 'NONE'
     options['report'] = 'NONE'
-    options['dryrun'] = True
+    if ROBOT_VERSION >= '2.8':
+        options['dryrun'] = True
+    else:
+        options['runmode'] = 'DryRun'
     options['output'] = 'suite_names.xml'
     options['outputdir'] = outs_dir
     options['stdout'] = StringIO()
     options['stderr'] = StringIO()
     options['monitorcolors'] = 'off'
-    options['monitormarkers'] = 'off'
+    if ROBOT_VERSION >= '2.8':
+        options['monitormarkers'] = 'off'
     return options
 
 def _options_for_rebot(options, datasources, start_time_string, end_time_string):
@@ -166,7 +174,8 @@ def _options_for_rebot(options, datasources, start_time_string, end_time_string)
     rebot_options['endtime'] = end_time_string
     rebot_options['output'] = rebot_options.get('output', 'output.xml')
     rebot_options['monitorcolors'] = 'off'
-    rebot_options['monitormarkers'] = 'off'
+    if ROBOT_VERSION >= '2.8':
+        options['monitormarkers'] = 'off'
     return rebot_options
 
 def _now():
